@@ -23,12 +23,16 @@ __credits__ = [
     'Adam Derewecki <derewecki@gmail.com>',
     'Peter Harrington <peter.b.harrington@gmail.com>',
     'Brett Hoerner <brett@bretthoerner.com>',
+    'Steven Johnson <sjohnson@yelp.com>',
     'Matt Jones <mattj@yelp.com>',
     'Julian Krause <juliank@yelp.com>',
+    'Robert Leftwich <rl.0x0@eml.cc>',
+    'Wahbeh Qardaji <wqardaji@yelp.com>',
     'Jimmy Retzlaff <jretz@yelp.com>',
     'Ned Rockson <ned@tellapart.com>',
     'Steve Spencer <steve@bigfrog.net>',
+    'Matthew Tai <mtai@adku.com>',
     'Paul Wais <pwais@yelp.com>',
 ]
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
