@@ -213,7 +213,7 @@ class EMRJobRunner(MRJobRunner):
     alias = 'emr'
 
     def __init__(self, **kwargs):
-        """:py:class:`EMRJobRunner` takes the same arguments as
+        """:py:class:`~mrjob.emr.EMRJobRunner` takes the same arguments as
         :py:class:`~mrjob.runner.MRJobRunner`, plus some additional options
         which can be defaulted in :py:mod:`mrjob.conf`.
 
@@ -261,7 +261,9 @@ class EMRJobRunner(MRJobRunner):
         :type num_ec2_instances: int
         :param num_ec2_instances: number of instances to start up. Default is ``1``.
         :type hadoop_streaming_jar_on_emr: str
-        :param hadoop_streaming_jar_on_emr: Like *hadoop_streaming_jar*, except that it points to a path on the EMR instance, rather than to a local file or one on S3. Rarely necessary.
+        :param hadoop_streaming_jar_on_emr: Like *hadoop_streaming_jar*, except that it points to a path on the EMR instance, rather than to a local file or one on S3. Rarely necessary to set this by hand.
+        :type hadoop_version: str
+        :param hadoop_version: Set the version of Hadoop to use on EMR. Currently can be ``'0.18'`` or ``'0.20'``. Default is ``'0.18'``, but will change to ``'0.20'`` (EMR's default) in v0.3.0 of :py:mod:`mrjob`.
         :type s3_endpoint: str
         :param s3_endpoint: Host to connect to when communicating with S3 (e.g. ``s3-us-west-1.amazonaws.com``). Default is to infer this from *aws_region*.
         :type s3_log_uri: str
@@ -374,6 +376,7 @@ class EMRJobRunner(MRJobRunner):
             'emr_endpoint',
             'emr_job_flow_id',
             'hadoop_streaming_jar_on_emr',
+            'hadoop_version',
             'num_ec2_instances',
             's3_endpoint',
             's3_log_uri',
@@ -391,6 +394,9 @@ class EMRJobRunner(MRJobRunner):
         return combine_dicts(super(EMRJobRunner, cls)._default_opts(), {
             'check_emr_status_every': 30,
             'ec2_instance_type': 'm1.small',
+            'hadoop_streaming_jar_on_emr':
+                '/home/hadoop/contrib/streaming/hadoop-streaming.jar',
+            'hadoop_version': '0.18',
             'num_ec2_instances': 1,
             's3_sync_wait_time': 5.0,
             'ssh_bin': 'ssh',
@@ -727,6 +733,8 @@ class EMRJobRunner(MRJobRunner):
         log.info('Creating Elastic MapReduce job flow')
         args = {}
 
+        args['hadoop_version'] = self._opts['hadoop_version']
+
         if self._opts['num_ec2_instances']:
             args['num_instances'] = str(self._opts['num_ec2_instances'])
 
@@ -839,7 +847,6 @@ class EMRJobRunner(MRJobRunner):
         if self._streaming_jar:
             return self._streaming_jar['s3_uri']
         else:
-            # this might be None, but that just means to use the default
             return self._opts['hadoop_streaming_jar_on_emr']
 
     def _launch_emr_job(self):
@@ -882,7 +889,7 @@ class EMRJobRunner(MRJobRunner):
 
             job_state = job_flow.state
             reason = getattr(job_flow, 'laststatechangereason', '')
-            log_uri = job_flow.loguri
+            log_uri = getattr(job_flow, 'loguri', '')
 
             # find all steps belonging to us, and get their state
             step_states = []
